<?php
require "../include/variables.php";
require "../include/functions.php";

if (isset($_GET['article']) && filter_var($_GET['article'], FILTER_VALIDATE_INT)) {
    $article = $_GET['article'];
} else {
    $article = "";
}
?>
<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" href="./src/css/style.css">
    <style>
    @media (prefers-color-scheme: dark) {
        .body {
            <?=$theme_dark?>
        }
    } 
    @media (prefers-color-scheme: light) {
        .body {
            <?=$theme_light?>
            }
        }
    </style>
    <link rel="icon" href="./src/img/favicon.ico">
    <title><?=$title?></title>
</head>
<body class="body">
    <header>
        <div class="pancontent">
            <div class="athena-container">
            <a href="<?=$root?>" class="athena-link">
                    <img src="./src/img/athena-mono.png" class="athena">
                </a>
            </div>
            <div class="content">
                <div>
                    <div class="main-title">
                        <div class="title"><?=$header_title?></div>
                        <div class="subtitle"><?=$header_subtitle?></div>
                    </div>
                </div>
            </div>
        </div>
    </header>
    <nav>
        <div class="pancontent">
            <?php nav($nav);?>
        </div>
    </nav>
    <main>
        <div class="content">
            <div>
                <div>
                    <?php
                        if ($article == "") {

                            $bdd = connect($dbhost, $dbname, $dbuser, $dbpass);
                            $search = isset($_GET['search']) ? "%" . htmlspecialchars($_GET['search']) . "%" : "%%";
                            $req = $bdd->prepare("SELECT ID, titre, date, auteur, image, resume FROM articles WHERE (titre LIKE :search OR ID LIKE :search OR auteur LIKE :search) AND classification <= :accreditation ORDER BY date DESC");
                            $req->bindParam(":search", $search);
                            $req->bindParam(":accreditation", $_SESSION['accreditation']);
                            $req->execute();
                            $resultat = $req->fetchAll(PDO::FETCH_ASSOC);

                            echo "<h1>Dernières infos du club</h1>";
                            echo "<form action='' method='get'><input type='text' placeholder='Article' name='search'><input type='submit' value='Rechercher'></form>";

                            if ($resultat) {
                                foreach($resultat as $row) {
                                    $date = strtotime($row['date']);
                                    echo '<div class="article-preview">';
                                    echo '<div class="article-illustration">';
                                    echo '<a href="?article=' . $row['ID'] . '" class="article-link"><img src="' . $row['image'] . '" class="article-miniature"></a>';
                                    echo '</div>';
                                    echo '<div class="article-details">';
                                    echo '<div class="article-data">n° ' . $row['ID'] . ' | ' . date('d/m/Y', $date) . ' | '. $row['auteur'] . '</div>';
                                    echo '<a href="?article=' . $row['ID'] . '" class="article-link">';
                                    echo '<div class="article-titre">' . $row['titre'] . '</div>';
                                    echo '</a>';
                                    echo '<div class="article-resume">' . $row['resume'] . '</div>';
                                    echo '</div>';
                                    echo '</div> ';
                                }
                            } else {
                                echo "Aucun article trouvé";
                            }

                        } else if (!isset($_GET['search']) && $article != "" && file_exists($wwwroot . '/content/journal/' . $article . '.md')) {
                            
                            $markdownContent = file_get_contents($wwwroot . '/content/journal/' . $article . '.md');

                            require_once '../include/parsedown.php';
                            $parsedown = new Parsedown();

                            $bdd = connect($dbhost, $dbname, $dbuser, $dbpass);
                            $req = $bdd->prepare("SELECT ID, titre, date, auteur, classification, image FROM articles WHERE ID = :article AND classification <= :accreditation");
                            $req->bindParam(":article", $article);
                            $req->bindParam(":accreditation", $_SESSION['accreditation']);
                            $req->execute();
                            $resultat = $req->fetchAll(PDO::FETCH_ASSOC);;

                            if ($resultat) {
                                $date = strtotime($resultat[0]['date']);
                                echo "<div class='article'><div class='article-info'>";
                                echo "<div class='article-titre'>" . $resultat[0]['titre'] . "</div>";
                                echo "<div class='article-date'>" . date('d/m/Y', $date) . "</div>";
                                echo "<div class='article-auteur'>" . $resultat[0]['auteur'] . "</div>";
                                echo "<div class='article-classification'>" . $classifications[$resultat[0]['classification']] . "</div></div>";
                                echo "<div class='article-illustration'><img src='" . $resultat[0]['image'] . "' class='article-miniature'/></div>";
                                echo "<div class='article-content'>";
                                echo $parsedown->text($markdownContent);
                                echo "</div></div></div>";
                            }
                        }
                    ?>
                </div>
            </div>
        </div>
    </main>
    <footer>
        <div class="content">
            <div>
                <div><?=$copyright?></div>
            </div>
        </div>
    </footer>
</body>
</html>